pub enum Error {
Show 13 variants
IdentifierIsEmpty,
IdentifierIllegalChars(char),
IllegalIdentifier {
context: &'static str,
},
ExpectedDirectory {
path: PathBuf,
},
ExpectedFile {
path: PathBuf,
},
IllegalSymlink {
path: PathBuf,
context: &'static str,
},
IllegalSymlinkTarget {
path: PathBuf,
},
CyclicSymlinks {
path: PathBuf,
},
IoPath {
path: PathBuf,
context: &'static str,
source: Error,
},
InvalidSegmentPath {
path: PathBuf,
context: String,
},
InternalError {
context: String,
},
ParseError(String),
WriteError(Box<dyn Error + Send + Sync>),
}Expand description
Error type for voa-core
Variants
IdentifierIsEmpty
Identifier is illegal because it consists of the empty string
IdentifierIllegalChars(char)
Identifier contains illegal characters
IllegalIdentifier
Identifier is illegal
ExpectedDirectory
Expected a directory, but found a different entry
ExpectedFile
Expected a file, but found a different entry
IllegalSymlink
Illegal symlink found
Fields
IllegalSymlinkTarget
Illegal symlink target found during canonicalization
CyclicSymlinks
Cyclic symlinks found during canonicalization
IoPath
An I/O error occurred at a path.
Fields
InvalidSegmentPath
A path is not a valid segment path.
Fields
InternalError
An internal error signals an inconsistency in voa-core. Those should never happen, they signal a logic error in the implementation.
ParseError(String)
A winnow parser for a type failed and produced and error.
WriteError(Box<dyn Error + Send + Sync>)
A write error occurred.
Use this variant for generic errors when writing verifiers to VOA hierarchies.